"""Smoke test — proves the package imports and version is set."""

from __future__ import annotations

import mgf.vm.firecracker as adapter


def test_version_set() -> None:
    assert hasattr(adapter, "__version__")
    parts = adapter.__version__.split(".")
    assert len(parts) >= 2
    assert all(p.isdigit() for p in parts[:2])


def test_all_is_a_list() -> None:
    assert isinstance(adapter.__all__, list)
    assert "__version__" in adapter.__all__
