"""TS-21 — canonical smoke."""

from __future__ import annotations

import pytest

pytestmark = [pytest.mark.smoke]


def test_imports() -> None:
    import mgf.vm.firecracker as m

    assert isinstance(m.__version__, str) and m.__version__
